# Mailchimp changelog

## [0.1.6] - 2026-01-16
- Updated connector definition (YAML version 1.0.1)
- Source commit: a50c8f71
- SDK version: 0.1.0

## [0.1.5] - 2026-01-16
- Updated connector definition (YAML version 1.0.1)
- Source commit: 49673b7b
- SDK version: 0.1.0

## [0.1.4] - 2026-01-16
- Updated connector definition (YAML version 1.0.1)
- Source commit: ca5acdda
- SDK version: 0.1.0

## [0.1.3] - 2026-01-15
- Updated connector definition (YAML version 1.0.1)
- Source commit: fa9a3b02
- SDK version: 0.1.0

## [0.1.2] - 2026-01-15
- Updated connector definition (YAML version 1.0.1)
- Source commit: 61a2e822
- SDK version: 0.1.0

## [0.1.1] - 2026-01-15
- Updated connector definition (YAML version 1.0.1)
- Source commit: 35211193
- SDK version: 0.1.0

## [0.1.0] - 2026-01-15
- Updated connector definition (YAML version 1.0.1)
- Source commit: 27e30ae3
- SDK version: 0.1.0
